@@ -18,10 +18,10 @@ import black
 import isort
 import pyupgrade._main
 from black.mode import TargetVersion
-from black.parsing import InvalidInput, lib2to3_parse
+from black.parsing import lib2to3_parse
 from isort.exceptions import FileSkipComment
 
-__version__ = "0.10.7"
+__version__ = "2023.2.1"
 __all__ = ["shed", "docshed"]
 
 # Conditionally imported in refactor mode to reduce startup latency in the common case
@@ -54,6 +54,7 @@ def shed(
     source_code: str,
     *,
     refactor: bool = False,
+    is_pyi: bool = False,
     first_party_imports: FrozenSet[str] = frozenset(),
     min_version: Tuple[int, int] = _default_min_version,
     _location: str = "string passed to shed.shed()",
@@ -73,15 +74,7 @@ def shed(
     # Use black to autodetect our target versions
     target_versions = {k for k, v in _version_map.items() if v >= min_version}
     try:
-        # Black errors out if we have pattern matching (3.10+), and the target versions
-        # include older versions.  Very well; we'll add a temporary workaround.
-        try:
-            parsed = lib2to3_parse(source_code.lstrip(), target_versions)
-        except InvalidInput as err:
-            if not re.match(r"Cannot parse: \d+:\d+: match ", str(err)):
-                raise
-            target_versions = {k for k, v in _version_map.items() if v >= (3, 10)}
-            parsed = lib2to3_parse(source_code.lstrip(), target_versions)
+        parsed = lib2to3_parse(source_code.lstrip(), target_versions)
         # black.InvalidInput, blib2to3.pgen2.tokenize.TokenError, SyntaxError...
         # for forwards-compatibility I'm just going general here.
     except Exception as err:
@@ -154,7 +147,7 @@ def shed(
     # One tricky thing: running `isort` or `autoflake` can "unlock" further fixes
     # for `black`, e.g. "pass;#" -> "pass\n#\n" -> "#\n".  We therefore run it
     # before other fixers, and then (if they made changes) again afterwards.
-    black_mode = black.Mode(target_versions=target_versions)  # type: ignore
+    black_mode = black.Mode(target_versions=target_versions, is_pyi=is_pyi)  # type: ignore
     source_code = blackened = black.format_str(source_code, mode=black_mode)
 
     pyupgrade_min = min(min_version, max(pyupgrade._plugins.imports.REPLACE_EXACT))
@@ -166,7 +159,7 @@ def shed(
         source_code = pyupgrade._main._fix_plugins(source_code, settings=pu_settings)
     source_code = pyupgrade._main._fix_tokens(source_code)
 
-    if refactor:
+    if refactor and not is_pyi:
         source_code = _run_codemods(source_code, min_version=min_version)
 
     try:
