@@ -167,6 +167,9 @@ class ShedFixers(VisitorBasedCodemodCommand):
         )
     )
     def remove_pointless_parens_around_call(self, _, updated_node):
+        # Don't remove whitespace if it includes comments
+        if m.findall(updated_node, m.Comment()):
+            return updated_node
         # This is *probably* valid, but we might have e.g. a multi-line parenthesised
         # chain of attribute accesses ("fluent interface"), where we need the parens.
         noparens = updated_node.with_changes(lpar=[], rpar=[])
@@ -176,6 +179,40 @@ class ShedFixers(VisitorBasedCodemodCommand):
         except SyntaxError:
             return updated_node
 
+    @m.leave(m.Call(func=oneof_names("dict", "list", "tuple"), args=[]))
+    def replace_builtin_with_literal(self, _, updated_node):
+        if updated_node.func.value == "dict":
+            return cst.Dict([])
+        elif updated_node.func.value == "list":
+            return cst.List([])
+        else:
+            assert updated_node.func.value == "tuple"
+            return cst.Tuple([])
+
+    @m.leave(
+        m.Call(
+            func=oneof_names("dict", "list", "tuple"),
+            args=[m.Arg(m.Dict([]) | m.List([]) | m.SimpleString() | m.Tuple([]))],
+        )
+    )
+    def replace_builtin_empty_collection(self, _, updated_node):
+        val = updated_node.args[0].value
+        val_is_empty_seq = (
+            isinstance(val, (cst.Dict, cst.List, cst.Tuple)) and not val.elements
+        )
+        val_is_empty_str = (
+            isinstance(val, cst.SimpleString) and val.evaluated_value == ""
+        )
+        if not (val_is_empty_seq or val_is_empty_str):
+            return updated_node
+        elif updated_node.func.value == "dict":
+            return cst.Dict([])
+        elif updated_node.func.value == "list":
+            return cst.List([])
+        else:
+            assert updated_node.func.value == "tuple"
+            return cst.Tuple([])
+
     # The following methods fix https://pypi.org/project/flake8-comprehensions/
 
     @m.leave(m.Call(func=m.Name("list"), args=[m.Arg(m.GeneratorExp())]))
